package edu.msoe.se2890.supplied.sampleProgram;

import java.util.Scanner;
import edu.msoe.se2890.supplied.PCMindstormProxy;

/**
 * This class represents a sample program for the Lego Mindstorms proxy. In
 * essence, it will simply take a command and transmit it to the lego mindstorm.
 * The values that are returned from the lego are printed out to the console. If
 * the use enter a number, it will be transmitted to the mindstorm. If the user
 * enters -1, the program will shut down.
 * 
 * @author schilling
 * 
 */
public class MindstormProxyUser {

	public class TestClass implements Runnable {
		private PCMindstormProxy sender;
		private boolean keepGoing = true;

		public TestClass(PCMindstormProxy sender2) {
			super();
			this.sender = sender2;
		}
		
		public void stopTestClass()
		{
			keepGoing = false;
		}

		@Override
		public void run() {
			int x = 0;
			// Sleep for 5 seconds to let the connectoon get estabolished successfully.
			try {
				Thread.sleep(5000);
			} catch (InterruptedException e1) {
				// TODO Auto-generated catch block
				e1.printStackTrace();
			}
			while (keepGoing == true) {
				sender.enqueue(x);
				x++;
				System.out.println("Enquing " + x);
				try {
					Thread.sleep(100);
				} catch (InterruptedException e) {
				}
			}
		}
	}

	public static void main(String[] args) throws InterruptedException {

		// Start the proxy and its thread.
		final PCMindstormProxy sender = PCMindstormProxy.getSingleton(PCMindstormProxy.BLUETOOTHPROXY);
		Thread t1 = new Thread(sender);
		t1.start();

		// Start the thread which will read from the proxy.
		MindstormProxyUser me = new MindstormProxyUser();

		boolean keepGoing = true;
		
		Thread t2 = new Thread(new Runnable() {
			@Override
			public void run() {
				while (true) {
					System.out.println("Received: " + sender.receiveInt());
				}
			}
		});
		t2.setDaemon(true);
		t2.start();

		// Instantiate a new test class which will generate random data to send
		// to the robot.
		TestClass myTester = me.new TestClass(sender);
		Thread t3 = new Thread(myTester);
		t3.start();

		// Instantiate a new keyboard input.
		Scanner kbd = new Scanner(System.in);

		while (keepGoing == true) {
			// Read the next entry from the keypad. If it is not -1, enqueue it
			// for transmit.
			int valueToTransmit = kbd.nextInt();
			if (valueToTransmit == -1) {
				sender.shutdown();
				keepGoing = false;
			} else {
				sender.enqueue(valueToTransmit);
			}
		}

		// Wait for the threads to die off that we care about.
		t1.join();
		myTester.stopTestClass();
		t3.join();
	}

}
